==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-italian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","Re");
define("_SUBJECT","Soggetto");
define("_PRIVATEMESSAGES","I Tuoi Messaggi Privati");
define("_CHECKALL","Controlla Tutto");
define("_FROM","Da");
define("_DATE","Data");
define("_DONTHAVEMESSAGES","Non hai ricevuto nessun Messaggio");
define("_NOTREAD","Non letto");
define("_MSGSTATUS","Status Messaggi");
define("_PRIVATEMESSAGE","Messaggi Privati");
define("_INDEX","Indice");
define("_SENT","Invia");
define("_PREVIOUSMESSAGE","Messaggio Precedente");
define("_NEXTMESSAGE","Prossimo Messaggio");
define("_PROFILE","Profilo");
define("_ABOUTPOSTING","About Posting");
define("_ALLREGCANPOST","Tutti gli Utenti Registrati possono inviare messaggi privati");
define("_TO","A");
define("_MESSAGEICON","Icona Messaggio");
define("_MESSAGE","Messaggio");
define("_HTML","HTML");
define("_PMON","On");
define("_PMOFF","Off");
define("_BBCODE","BBCode");
define("_WROTE","scrive");
define("_OPTIONS","Opzioni");
define("_HTMLDISSABLE","Disattiva HTML in questo Post");
define("_BBCODEDISSABLE","Disattiva <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> in questo Post");
define("_SMILEDISSABLE","Disattiva <a href=\"bb_smilies.php\" target=\"_blank\"><i>smilies</i></a> in questo Post");
define("_CANCELREPLY","Cancella Replica");
define("_CANCELSEND","Cancella Invio");
define("_CLEAR","Pulisci");
define("_SUBMIT","Invia");
define("_USERNOTINDB","L'Utente selezionato non esiste nel database.");
define("_CHECKNAMEANDTRY","Controlla bene il nome e prova ancora.");
define("_MSGPOSTED","Il tuo Messaggio &egrave; stato Inviato.");
define("_RETURNTOPMSG","Clicca qui per ricaricare i tuoi messaggi privati.");
define("_MSGDELETED","I Tuoi Messaggi sono stati Cancellati.");
define("_BBGO","vai");
define("_BBNEWPMSG","Nuovi messaggi");
define("_BBNONEWPMSG","Nessun nuovo messaggio");
define("_BBTOTALPMSG","Messaggi totali");
define("_BBEMPTYPMSG","Non hai alcun messaggio");
define("_BBLOGIN","Fai il Login per controllare i tuoi messaggi privati");
define("_BBPMSG","Messaggio privato");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Seleziona un Forum");
define("_BBNOFORUM","Nessun nuovo Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Clicka sullo Smilies per inserirlo nel messaggio:");
define("_CLICKCODEBUTTONS","Clicka sui seguenti pulsanti per aggiungere BBCode al tuo messaggio:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-italian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","Re");
define("_SUBJECT","Soggetto");
define("_PRIVATEMESSAGES","I Tuoi Messaggi Privati");
define("_CHECKALL","Controlla Tutto");
define("_FROM","Da");
define("_DATE","Data");
define("_DONTHAVEMESSAGES","Non hai ricevuto nessun Messaggio");
define("_NOTREAD","Non letto");
define("_MSGSTATUS","Status Messaggi");
define("_PRIVATEMESSAGE","Messaggi Privati");
define("_INDEX","Indice");
define("_SENT","Invia");
define("_PREVIOUSMESSAGE","Messaggio Precedente");
define("_NEXTMESSAGE","Prossimo Messaggio");
define("_PROFILE","Profilo");
define("_ABOUTPOSTING","About Posting");
define("_ALLREGCANPOST","Tutti gli Utenti Registrati possono inviare messaggi privati");
define("_TO","A");
define("_MESSAGEICON","Icona Messaggio");
define("_MESSAGE","Messaggio");
define("_HTML","HTML");
define("_PMON","On");
define("_PMOFF","Off");
define("_BBCODE","BBCode");
define("_WROTE","scrive");
define("_OPTIONS","Opzioni");
define("_HTMLDISSABLE","Disattiva HTML in questo Post");
define("_BBCODEDISSABLE","Disattiva <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> in questo Post");
define("_SMILEDISSABLE","Disattiva <a href=\"bb_smilies.php\" target=\"_blank\"><i>smilies</i></a> in questo Post");
define("_CANCELREPLY","Cancella Replica");
define("_CANCELSEND","Cancella Invio");
define("_CLEAR","Pulisci");
define("_SUBMIT","Invia");
define("_USERNOTINDB","L'Utente selezionato non esiste nel database.");
define("_CHECKNAMEANDTRY","Controlla bene il nome e prova ancora.");
define("_MSGPOSTED","Il tuo Messaggio &egrave; stato Inviato.");
define("_RETURNTOPMSG","Clicca qui per ricaricare i tuoi messaggi privati.");
define("_MSGDELETED","I Tuoi Messaggi sono stati Cancellati.");
define("_BBGO","vai");
define("_BBNEWPMSG","Nuovi messaggi");
define("_BBNONEWPMSG","Nessun nuovo messaggio");
define("_BBTOTALPMSG","Messaggi totali");
define("_BBEMPTYPMSG","Non hai alcun messaggio");
define("_BBLOGIN","Fai il Login per controllare i tuoi messaggi privati");
define("_BBPMSG","Messaggio privato");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Seleziona un Forum");
define("_BBNOFORUM","Nessun nuovo Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Clicka sullo Smilies per inserirlo nel messaggio:");
define("_CLICKCODEBUTTONS","Clicka sui seguenti pulsanti per aggiungere BBCode al tuo messaggio:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
